
/*
Design by Free CSS Templates
http://www.freecsstemplates.org
Released for free under a Creative Commons Attribution 2.5 License
*/

* {
	margin: 0;
	padding: 0;
}

body {
	margin-top: 40px;
	background: #1A1A1A;
	text-align: justify;
	font-family: Arial, Helvetica, sans-serif;
	font-size: 13px;
	color: #A1A1A1;
}

h1, h2, h3 {
	/* color: #AA2808; */
        color: #07B6FE;
}

h1 {
}

h2 {
}

h3 {
}

p, blockquote, ul, ol {
	margin-bottom: 20px;
	line-height: 2em;
}

p {
}

blockquote {
}

li {
  margin: 0px 0 0px 16px;
}

#sidebar ul, #sidebar ol, #sidebar li {
	margin: 0px;
	padding: 0px;
	list-style: none;
}

a {
	text-decoration: underline;
	color: #07B6FE;
}

a:hover {
	text-decoration: none;
	color: #838383;
}

/* Wrapper */

#wrapper {
}

/* Header */

#header {
	width: 880px;
	height: 91px;
	margin: 0 auto;
}

/* Logo */

#logo {
	float: left;
	width: 270px;
	height: 76px;
	margin: 0px;
	padding: 15px 0px 0px 0px;
}

#logo h1 {
	margin: 0;
	padding: 0;
	font: normal 36px Georgia, "Times New Roman", Times, serif;
}

#logo h2 {
	margin: -2px 0 0 0;
	padding: 0;
	text-transform: uppercase;
	letter-spacing: 2px;
	font-size: 10px;
	font-weight: bold;
	color: #444444;
}

#logo a {
	text-decoration: none;
	color: #F0F0F0;
}

/* Menu */

#menu {
	width: 940px;
	height: 60px;
	margin: 0 auto;
}

#menu ul {
	margin: 0;
	padding: 20px 0 0 0px;
	list-style: none;
	line-height: normal;
	margin-left: 30px;
}

#menu li {
	display: inline;
	text-align: center;
}

#menu a {
	display: block;
	float: left;
	margin-right: 3px;
	padding: 5px 20px 5px 20px;
	text-decoration: none;
	text-align: center;
	text-transform: uppercase;
	font-size: 11px;
	font-weight: bold;
	color: #07B6FE;
}

#menu a:hover, #menu .active a {
	background: #07B6FE;
	color: #FFFFFF;
}

#splash {
	width: 940px;
	height: 410px;
	margin: 0 auto;
}

/* Search */

#header-search {
	width: 940px;
	height: 51px;
	margin: 0 auto;
	padding: 0px 0px 0px 0px;
}

#header-search form {
	float: right;
	width: 300px;
	margin: 0;
	padding: 12px 0px 0px 0px;
}

#header-search fieldset {
	margin: 0;
	padding: 0;
	border: none;
}

#header-search-text {
	width: 200px;
	padding: 2px 3px;
	background: #1E1E1E;
	border: none;
	color: #4D4D4D;
}

#header-search-submit {
	background: none;
	border: none;
	font-family: Arial, Helvetica, sans-serif;
	font-size: 12px;
	color: #E4E4E4;
}

#search {
	height: 51px;
	margin: 0 auto;
	padding: 0px 0px 60px 0px;
}

#search form {
	margin: 0;
	padding: 12px 0px 0 0;
}

#search fieldset {
	margin: 0;
	padding: 0;
	border: none;
}

#search input {
	float: left;
	font: 12px Arial, Helvetica, sans-serif;
}

#search-text {
	width: 160px;
	height: 18px;
	padding: 3px 0 3px 5px;
	border: none;
	color: #000000;
}

#search-submit {
	margin-left: 10px;
	padding: 4px 4px;
	border: none;
	background: #07B6FE;
	color: #FFFFFF;
}

/* Page */

#page {
	width: 940px;
	margin: 0 auto;
}

#page-bgtop {
}

/* Content */

#content {
	float: right;
	width: 640px;
}
.post {
	margin: 0px 0px 30px 0px;
	border-bottom: 1px solid #252726;
}

.post .title {
	margin: 0px;
	padding: 0px 0px 5px 0px;
	color: #232F01;
}

.post .title a {
	padding: 4px 35px 4px 15px;
	background: #07B6FE;
	text-decoration: none;
	font-weight: normal;
	color: #FFFFFF;
}

.post .date {
	padding: 0 0 0 15px;
	margin: 0;
	color: #707070;
}

.post .entry {
	padding: 20px 0px;
}

.post img {
	float: left;
	padding: 15px 0px;
}

.post .meta {
	text-align: right;
	padding: 0px 0 20px 0;
	font-weight: bold;
	color: #202020;
}

.post .byline {
	float: right;
	margin-top: -30px;
	font-size: 12px;
	font-weight: bold;
	color: #5E5E5E;
}

/* Pager */

.pager {
	margin: 4em 0 0 0;
}

.pager .previous {
	float: left;
}

.pager .next {
	float: right;
}

/* Sidebar */

#sidebar {
	float: left;
	width: 240px;
	margin: 0px;
	padding: 0px 30px 30px 0px;
}

#sidebar ul {
	margin: 0;
	padding: 0;
	list-style: none;
	line-height: normal;
}

#sidebar li {
	margin-bottom: 1px;
}

#sidebar li ul {
	margin: 0px;
	padding: 0px 0px 40px 0px;
}

#sidebar li li {
	margin: 0;
	padding: 9px 0px;
	border: none;
	border-bottom: 1px solid #252726;
}

#sidebar h2 {
	margin: 0px;
	padding: 0px 0px 20px 0px;
	font-size: 160%;
	font-weight: normal;
	color: #07B6FE;
}

#sidebar h3 {
	font-size: 77%;
	color: #110404;
}

#sidebar p {
	margin: 0 0 1.5em 0;
	line-height: normal;
	color: #D4C792;
}

#sidebar a {
	border: none;
	text-decoration: none;
	color: #A1A1A1;
}

#sidebar a:hover {
	text-decoration: underline;
}

/* Submenu */

#submenu {
}

/* News */

#news {
}

#news a {
	font-size: 85%;
}

/* Footer */

#footer {
	width: 940px;
	margin: 0 auto;
	padding: 20px 0px;
	border-top: 1px solid #252726;
	color: #FFFFFF;
}

#footer p {
	margin: 0;
	text-align: center;
	font-size: 77%;
}

#footer a {
	text-decoration: underline;
}

#footer a:hover {
	text-decoration: none;
}
